import os
import pandas as pd

# Define the directory path
directory_path = r'C:\\Users\\user\\projects\\myproject'

# List to store code blocks
code_blocks = []

# Directories to include and process recursively
include_dirs = {'static', 'templates'}

# Files to include in the top-level directory
include_files = {
    '.env', 'app.py', 'backtester.py', 'tock1.txt', 'config.yaml',
    'conversation_log.csv', 'data_fetcher.py', 'notifier.py', 'optimized_strategy.py',
    'stock_trading_env.py', 'strategy.py', 'test_get_access_token.py', 'trading_system.py',
    'train_agent.py', 'transactions.log', 'urls.py', 'utils.py', 'visualizer.py', 'wsgi.py'
}

def is_file_included(file, include_files):
    return file in include_files

# Function to process files in the top-level directory
def process_top_level_files(directory):
    for filename in os.listdir(directory):
        file_path = os.path.join(directory, filename)
        if os.path.isfile(file_path) and is_file_included(filename, include_files):
            try:
                with open(file_path, 'r', encoding='utf-8') as file:
                    code = file.read()
            except UnicodeDecodeError:
                with open(file_path, 'r', encoding='latin-1') as file:
                    code = file.read()
            code_blocks.append({
                "name": os.path.relpath(file_path, directory),  # Save file name as relative path
                "code": code
            })
            print(f"Reading file: {file_path}")  # Debugging line for files being read

# Function to process files in the specified subdirectories and their subdirectories
def process_subdirectory_files(directory):
    for root, _, files in os.walk(directory):
        for filename in files:
            file_path = os.path.join(root, filename)
            try:
                with open(file_path, 'r', encoding='utf-8') as file:
                    code = file.read()
            except UnicodeDecodeError:
                with open(file_path, 'r', encoding='latin-1') as file:
                    code = file.read()
            code_blocks.append({
                "name": os.path.relpath(file_path, directory),  # Save file name as relative path
                "code": code
            })
            print(f"Reading file: {file_path}")  # Debugging line for files being read

# Process top-level directory for specific files
print(f"Processing top-level directory: {directory_path}")
process_top_level_files(directory_path)

# Process specified subdirectories and their nested subdirectories
for subdirectory in include_dirs:
    subdirectory_path = os.path.join(directory_path, subdirectory)
    if os.path.isdir(subdirectory_path):
        print(f"Processing subdirectory: {subdirectory_path}")
        process_subdirectory_files(subdirectory_path)

# Convert to pandas DataFrame
df = pd.DataFrame(code_blocks)

# Save to CSV file on the F: drive
csv_path = r'F:\\code_blocks.csv'
df.to_csv(csv_path, index=False, encoding='utf-8')

print(f"CSV file successfully saved to {csv_path}!")
